import requests
import json
import random
import string
import click

def ipleak():
    requestv4 = requests.get("https://ipv4.ipleak.net/json/")

    if requestv4.status_code == 200:
        datav4 = requestv4.json()
        print(f"IPv4: {datav4['ip']}")

    try:
        requestv6 = requests.get("https://ipv6.ipleak.net/json/")
        datav6 = requestv6.json()
        print(f"IPv6: {datav6['ip']}")
    except Exception as e:
        pass

    if datav4:
        print(f"{datav4['country_name']} - {datav4['city_name']}")

    try:
        requestdns = requests.get(
        f"https://{get_random_string(40)}.ipleak.net/json/")
        if requestdns.status_code == 200:
            datadns = requestdns.json()
            print(
                f"DNS: {datadns['ip']} - {datadns['country_name']} - {datadns['city_name']}")
    except Exception as e:
        pass


def get_random_string(length):
    letters = string.ascii_lowercase
    result_str = ''.join(random.choice(letters) for i in range(length))
    return result_str

@click.command()
def main():
    ipleak()

if __name__ == "__main__":
    main()


from setuptools import setup, find_packages
from os import path

with open("./requirements.txt") as f:
    required = f.read().splitlines()

this_directory = path.abspath(path.dirname(__file__))
with open(path.join(this_directory, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(name='ipleak',
      version='0.1.1',
      description='Python Tool to check your VPN.',
      long_description=long_description,
      author='profileid',
      author_email='profileid@protonmail.com',
      url="https://github.com/ProfileID/ipleak",
      license='MIT',
      packages=['ipleak'],
      install_requires=required,
      entry_points={
          "console_scripts": ["ipleak = ipleak.__main__:main"]
      },
      classifiers=[
          'Programming Language :: Python :: 3.6',
          'Programming Language :: Python :: 3.7',
          'Programming Language :: Python :: 3.8'
      ]
      )
